#!/bin/bash
trap "exit 1" TERM
export TOP_PID=$$
source $(dirname "$0")/../../../scripts/deployHelpers/deployHelperFunc.sh
source $(dirname "$0")/../../../scripts/deployHelpers/validateDeployment.sh

echo "####################################################################"
echo "Deploying $(dirname "$0")"
echo "####################################################################"


# move to current script dir
cd "$(dirname "$0")"

cd ..

# build
WORKDIR="dist"
if [ -d "$WORKDIR" ]; then rm -Rf $WORKDIR; fi
mkdir $WORKDIR

# copy everything and resolve links excluding node_modules. GCP adds those for us
rsync -avL . $WORKDIR --exclude $WORKDIR --exclude='_defs' --exclude='reference'  --exclude='sm-templates' --exclude='node_modules' --exclude='.history' --exclude='scripts'

cd $WORKDIR

###########################################################
# If you update the timeout of the cloud function deployment
# you also need to update the timeout on the redis lock
# see getRunLock, constant: lockTimeout
###########################################################

# deploy
case "$1" in


    kstestcloud1)
        checkGCloudProj "kaleidotestcloud1"
        ;;


    
    kstestcloud2)
        checkGCloudProj "kaleidotestcloud2a"
        ;;



    kstestcloud3)
        checkGCloudProj "kaleidotestcloud3a"
        ;;

		


    stage)
        checkGCloudProj "kaleidosimtestenv"
        ;;



    prod | prod_fast)
        checkGCloudProj "vertical-karma-207307"
        # djs -> might want to comment this line out later as we don't need this function in production after initial testing is done
        ;;

    *)
        echo "Not deploying"
        ;;
esac

STATE=$?
checkDeploymentStatus "Cloud Companion" $STATE $1 $2

echo "####################################################################"
echo "Completed deploy script for $(dirname "$0")"
echo "####################################################################"